﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using C1.C1Preview;

namespace C1PrintDocument_PreviewVsView
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // use a specialized class to store VP files
        private class VPFile
        {
            string _path;
            public VPFile(string path)
            {
                _path = path;
            }
            public override string ToString()
            {
                return Path.GetFileName(_path);
            }
            public string FullPath
            {
                get { return _path; }
            }
        }

        // load available VSView documents into list
        private void Form1_Load(object sender, EventArgs e)
        {
            string path = Application.StartupPath;
            int pos = path.IndexOf(@"\bin");
            path = path.Substring(0, pos) + @"\VPDocs";
            foreach (string file in Directory.GetFiles(path, "*.vp"))
                comboBox1.Items.Add(new VPFile(file));
        }

        // user selected a document, show it in C1PrintPreview
        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            // load selected document into VSView control
            string fileName = ((VPFile)comboBox1.SelectedItem).FullPath;
            loadVP(fileName);
        }
       
        // loads the specified VSPrinter document into the preview
        private void loadVP(string fileName)
        {
            try
            {
                c1PrintPreviewControl1.PreviewPane.Busy = true;
                _vp.LoadDoc(fileName, false);
                // add pages to C1PrintPreviewControl control
                C1PrintDocument doc = new C1PrintDocument();
                for (short page = 1; page <= _vp.PageCount; ++page)
                {
                    _vp.PreviewPage = page;
                    doc.PageLayout.PageSettings.TopMargin = 0;
                    doc.PageLayout.PageSettings.LeftMargin= 0;
                    if (_vp.Picture.Height< _vp.Picture.Width )
                       doc.PageLayout.PageSettings.Landscape = true;
                    else
                        doc.PageLayout.PageSettings.Landscape = false ;
                    doc.Body.Children.Add(new RenderImage(_vp.Picture));
                   
                }
                c1PrintPreviewControl1.Document = doc;
            }
            catch
            {
                MessageBox.Show(string.Format("Error loading {0}", fileName));
            }
            finally
            {
                c1PrintPreviewControl1.PreviewPane.Busy = false;
            }
        }
      
    }
}
